==> deepin-device-formatter-0.0.1.6-1.src.tar.gz: dde-device-formatter-0.0.1.6/translations/dde-device-formatter.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="42"/>
        <source>Format successful</source>
        <translation>Format successful</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="47"/>
        <source>Formatting the disk, please wait...</source>
        <translation>Formatting the disk, please wait...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="119"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="137"/>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="146"/>
        <source>Quick Format</source>
        <translation>Quick Format</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="163"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>Formatting will erase all data on the disk.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="88"/>
        <location filename="../view/mainwindow.cpp" line="106"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="162"/>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="167"/>
        <source>Formatting...</source>
        <translation>Formatting...</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="193"/>
        <source>Done</source>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="199"/>
        <source>Quit</source>
        <translation>Quit</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="200"/>
        <source>Your disk has been removed</source>
        <translation>Your disk has been removed</translation>
    </message>
    <message>
        <source>Your disk is removed when formatting</source>
        <translation type="vanished">Your disk is removed when formatting</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="203"/>
        <source>Failed to format the device</source>
        <translation>Failed to format the device</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="204"/>
        <source>Reformat</source>
        <translation>Reformat</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="43"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="55"/>
        <source>System Disk</source>
        <translation>System Disk</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="59"/>
        <source>%1 Encrypted</source>
        <translation>%1 Encrypted</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="61"/>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="90"/>
        <source>Device does not exist</source>
        <translation>Device does not exist</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>The device is read-only</source>
        <translation>The device is read-only</translation>
    </message>
    <message>
        <source>Cannot format local device</source>
        <translation type="vanished">Cannot format local device</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="43"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</translation>
    </message>
</context>
</TS>

==> deepin-device-formatter-0.0.1.15-2.src.tar.gz: dde-device-formatter-0.0.1.15/translations/dde-device-formatter.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="42"/>
        <source>Format successful</source>
        <translation>Format successful</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="49"/>
        <source>Formatting the disk, please wait...</source>
        <translation>Formatting the disk, please wait...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="119"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="137"/>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="146"/>
        <source>Quick Format</source>
        <translation>Quick Format</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="163"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>Formatting will erase all data on the disk.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="91"/>
        <location filename="../view/mainwindow.cpp" line="109"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="227"/>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="232"/>
        <source>Formatting...</source>
        <translation>Formatting...</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="258"/>
        <source>Done</source>
        <translation>Done</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="264"/>
        <source>Quit</source>
        <translation>Quit</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="265"/>
        <source>Your disk has been removed</source>
        <translation>Your disk has been removed</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="268"/>
        <source>Failed to format the device</source>
        <translation>Failed to format the device</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="269"/>
        <source>Reformat</source>
        <translation>Reformat</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="43"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="54"/>
        <source>System Disk</source>
        <translation>System Disk</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="58"/>
        <source>%1 Encrypted</source>
        <translation>%1 Encrypted</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="60"/>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>dde device formatter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Device does not exist</source>
        <translation>Device does not exist</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>The device is read-only</source>
        <translation>The device is read-only</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="43"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</translation>
    </message>
</context>
</TS>
